function [Icst Jcst]=ijcoast(rlon,rlat, lon,lat)

%% Convert coastline "lon,lat" data into fractional grid indices for
%% a 2D grid specified as a pair of 2D arrays "rlon,rlat".
%%
%% output:  Icst  => Coastline I-grid coordinates, [0:Lp-1]
%%          Jcst  => Coastline J-grid coordinates, [0:Mp-1]
%%


EXTRACT=1;
method='linear';

tic;
if (EXTRACT)
  disp(['ijcoast :: extracting coastline']);           %% Extract the needed
  dx=5*abs(mean(mean(gradient(rlon))));                %% portion of coasline
  dy=5*abs(mean(mean(gradient(rlat))));                %% data

  Llon=min(min(rlon))-dx;  Blat=min(min(rlat))-dy;
  Rlon=max(max(rlon))+dx;  Tlat=max(max(rlat))+dy;

  ind=find(lon < Llon | lon > Rlon | lat < Blat | lat > Tlat);

  disp(['ijcoast :: size of ind=' num2str(size(ind)) ])
  disp(['ijcoast :: size of lon=' num2str(size(lon)) ])

  clon=lon;
  clat=lat;
  if (~isempty(ind))
    clon(ind)=[];
    clat(ind)=[];
  end

  disp(['ijcoast :: size of clon=' num2str(size(clon)) ])

  Clon=[NaN; clon; NaN];
  Clat=[NaN; clat; NaN];

  disp(['ijcoast :: size of Clon=' num2str(size(Clon)) ])

  clear clon clat
else
  disp(['ijcoast :: just copying coastline, size=' num2str(size(lon)) ]);
  Clon=lon;  Clat=lat;
end

% Interpolate coastline to grid units.

disp(['ijcoast :: converting (lon,lat) into (I,J) grid indices...']);

[Lp,Mp]=size(rlon);  [y,x]=meshgrid(1:Mp,1:Lp);

Icst=griddata(rlon,rlat, x, Clon,Clat, method);
Jcst=griddata(rlon,rlat, y, Clon,Clat, method);

Icst=Icst-1;    %% subtract 1 to bring the indices 
Jcst=Jcst-1;    %% into the range [0:Lp-1, 0:Mp-1]

% Save into a Matlab file.

ijfname='ijcoast.mat';
disp(['ijcoast :: saving coastline (I,J) into ' ijfname ' file']);
save(ijfname, 'Icst', 'Jcst');
toc;
return
