function [h]=pltmask(grid_file,ptype,coast_file);

 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Hernan G. Arango %%%%
% Copyright (c) 2001 Rutgers University.                               %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                      %
% function [h]=pltmask(grid_file,C);                                   %
%                                                                      %
% This function plots the land/sea mask. If appropriate, It also       %
% ovelays the given coastline data.                                    %
%                                                                      %
%                                                                      %
% On Input:                                                            %
%                                                                      %
%    grid_file   NetCDF file name (character string).                  %
%    ptype       plot type flag:                                       %
%                  ptype=0   => Cartesian axis.                        %
%                  ptype=1   => Spehrical axis.                        %
%    C           Coastline indices (structure array):                  %
%                  C.grid    => Grid file name.                        %
%                  C.coast   => Coastline file name.                   %
%                  C.indices => Coastline indices file name.           %
%                  C.lon     => Coastline longitudes.                  %
%                  C.lat     => Coastline latitudes.                   %
%                  C.Icst    => Coastline I-grid coordinates, (0:L).   %
%                  C.Jcst    => Coastline J-grid coordinates, (0:M).   %
%                                                                      %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


     ncid=netcdf.open(grid_file,'NOWRITE');
    varid=netcdf.inqVarID(ncid,'lon_rho');
     rlon=netcdf.getVar(ncid,varid);
    varid=netcdf.inqVarID(ncid,'lat_rho');
     rlat=netcdf.getVar(ncid,varid);
    varid=netcdf.inqVarID(ncid,'mask_rho');
     mask=netcdf.getVar(ncid,varid);
    netcdf.close(ncid)

%  Set coastline switch

if (nargin > 2)
    tic;                      %%% Read in coastline data and compute
    load(coast_file);         %%% compute (I,J) grid indices if needed.
    if (exist('C'))
      xcst=C.Icst;
      ycst=C.Jcst;
    elseif (exist('lon') & exist('lat'))
      xcst=C.Icst;
      ycst=C.Jcst;
    else
      error('Coast file should contain "lon" and "lat" vectors');
    end
    toc;
end

%-----------------------------------------------------------------------
% Plot mask of RHO-points.
%-----------------------------------------------------------------------

figure;
[Lp,Mp]=size(mask);
[x,y]=ndgrid(1:Lp,1:Mp);
cmask=mask*2+mod(mod(x,2)+mod(y,2),2);

if (ptype)
  h=surface(rlon,rlat,cmask); shading flat;
  colormap([0 1 0;.5 1 0;0 .7 1;.3 0 1]);
  set(gca,'layer','top');
  axis tight;
  grid on;
  hold on
  plot(C.lon,C.lat,'k');
  xlabel('Longitude');
  ylabel('Latitude');
else
  x=0:1:Lp-1; x=x';
  y=0:1:Mp-1;
  h=image(x,y,cmask','cdatamapping','scaled');
  colormap([0 1 0;.5 1 0;0 .7 1;.3 0 1]);
  set(gca,'YDir','normal','drawmode','fast','layer','top');
  grid on;
  hold on
  plot(C.Icst,C.Jcst,'k');
  xlabel('I-grid');
  ylabel('J-grid');
end
title('Land/Sea Mask of RHO-points');

return
