function pointer(shape)

%% Changes the mouse pointer. If called without arguments it restores to the
%% normal arrow. If the argument (a character string) matched one of the keys
%% below, then pointer shape is formed by the corresponding 16x16 image where
%% asterisk (*) stands for black color, plus sign (+) for white, and "o" for
%% transparent; "hs" specifies the point in the image to which the mouse
%% actually points, e.g. hs=[1,1] is upper-left corner; hs=[7,7] is in the
%% middle,  If the argument is supplied but does not match any of the keys,
%% then it is passed to the standard Matlab routine and, hopefully matches
%% something there.
%%
%% Andrey Shcherbina, shcherbina@apl.washington.edu, 11/20/2001

if (nargin==0)                             %%% Set default arrow pointer
  set(gcf,'pointer','arrow');
  return;
end

if (strcmp(lower(shape),'aim'))            %%% Customized pointers
  hs=[8,8];
  ptr=['ooooo++*++oooooo'
       'ooo++*****++oooo'
       'oo+**o+*+o**+ooo'
       'o+*ooo+*+ooo*+oo'
       'o+*oooo*oooo*+oo'
       '+*ooooo*ooooo*+o'
       '+*++ooooooo++*+o'
       '******ooo******o'
       '+*++ooooooo++*+o'
       '+*ooooo*ooooo*+o'
       'o+*oooo*oooo*+oo'
       'o+*ooo+*+ooo*+oo'
       'oo+**o+*+o**+ooo'
       'ooo++*****++oooo'
       'ooooo++*++oooooo'
       'oooooooooooooooo'];

elseif (strcmp(lower(shape),'zoom'))
  hs=[7,7];
  ptr=['oooo****oooooooo'
       'oo**++++**oooooo'
       'o*++++++++*ooooo'
       'o*+++**+++*ooooo'
       '*++++**++++*oooo'
       '*++******++*oooo'
       '*++******++*oooo'
       '*++++**++++*oooo'
       'o*+++**+++*ooooo'
       'o*++++++++**oooo'
       'oo**++++*****ooo'
       'oooo****ooo***oo'
       'oooooooooooo***o'
       'ooooooooooooo***'
       'oooooooooooooo*o'
       'oooooooooooooooo'];

elseif (strcmp(lower(shape),'rect'))
  hs=[5,5];
  ptr=['oooo*ooooooooooo'
       'oooo*+oooooooooo'
       'oooo*+oooooooooo'
       'oooo*+oooooooooo'
       '****o****ooooooo'
       'o+++*+++++oooooo'
       'oooo*+oooooooooo'
       'oooo*+oooooooooo'
       'oooo*+oo******oo'
       'ooooo+oo*++++*oo'
       'oooooooo*++++*oo'
       'oooooooo******oo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'];

elseif (strcmp(lower(shape),'point'))
  hs=[9,3];
  ptr=['oooooooooo*+oooo'
       'ooooooooo*+ooooo'
       'oooooooo*+oooooo'
       'oo*+ooo*+ooooooo'
       'oo*+oo*+oooooooo'
       'oo*+o*+ooooooooo'
       'oo*+*+oooooooooo'
       'oo**+ooooooooooo'
       'oo*+oooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'
       'oooooooooooooooo'];

elseif (strcmp(lower(shape),'archer'))
  hs=[1,1];
  ptr=['*****ooooooooooo'
       '**oooooooooooooo'
       '*o*ooooooooooooo'
       '*oo*oooooooooooo'
       '*ooo*ooooooooooo'
       'ooooo*oooooooooo'
       'oooooo**oooooooo'
       'oooooo****oooooo'
       'ooooooo*****oooo'
       'ooooooo*******oo'
       'oooooooo********'
       'oooooooo***ooooo'
       'ooooooooo**ooooo'
       'ooooooooo**ooooo'
       'oooooooooo*ooooo'
       'oooooooooo*ooooo'];

elseif (strcmp(lower(shape),'crosshair'))
  hs=[3,3];
  ptr=['oo*ooooooooooooo'
       'oo*ooooooooooooo'
       '*****ooooooooooo'
       'oo*ooooooooooooo'
       'oo*ooooooooooooo'
       'ooooo*oooooooooo'
       'oooooo**oooooooo'
       'oooooo****oooooo'
       'ooooooo*****oooo'
       'ooooooo*******oo'
       'oooooooo********'
       'oooooooo***ooooo'
       'ooooooooo**ooooo'
       'ooooooooo**ooooo'
       'oooooooooo*ooooo'
       'oooooooooo*ooooo'];
else
  set(gcf,'pointer',shape);
  return;
end

ptr=double(ptr);
ptr(ptr=='*')=1;
ptr(ptr=='+')=2;
ptr(ptr=='o')=NaN;
set(gcf,'pointer','custom', 'pointershapecdata',ptr, ...
                            'PointerShapeHotSpot',hs)
return
